function [] = tsg_mergesample_B( hMainFig )
%
% function [] = tsg_mergesample( hMainFig )
%
% Merge the 2 types of 'bucket' records
%
% Input
%
% Ouptut
%
% Sample of type WS only have SSPS parameter
% Sample of type EXT may have SSPS and SSTP parameters.
%
% When WS and EXT parameters are merge I must create a fake SSTP variable
% for WS type.
%

% Get bucket data in ASCII or NETCDF format. If the data does not exist
% getappdata return an empty matrix
% ---------------------------------------------------------------------
tsg  = getappdata( hMainFig, 'tsg_data');

% Get NO_CONTROL code value
% -------------------------
NO_CONTROL = get(tsg.qc.hash, 'NO_CONTROL', 'code');

% Create a temporary structure with one NaN
% No other solution as I can't add a structure to an empty one
% ------------------------------------------------------------
sample = struct('DAYD',   NaN,   'LATX',    NaN,   'LONX',      NaN, ...
                'SSPS',   NaN,   'SSPS_QC', NaN,   'SSPS_TYPE', 'UNKN',...
                'SSTP',   NaN,   'SSTP_QC', NaN,   'SSTP_TYPE', 'UNKN', ...
                'INDICE', NaN );

% Fill the structure sample with the bucket data.
% WS exist only for SSPS 
% ------------------------------------------------
if ~isempty( tsg.DAYD_WS )

  sample.DAYD = [sample.DAYD; tsg.DAYD_WS];
  sample.LATX = [sample.LATX; tsg.LATX_WS];
  sample.LONX = [sample.LONX; tsg.LONX_WS];
  sample.SSPS = [sample.SSPS; tsg.SSPS_WS];
  sample.SSTP = [sample.SSTP; NaN*ones(size(tsg.DAYD_WS)) ];
  
  if ~isempty(tsg.SSPS_WS_QC)
    sample.SSPS_QC = [int8(sample.SSPS_QC); tsg.SSPS_WS_QC ];
  else
    sample.SSPS_QC = [int8(sample.SSPS_QC); ...
                      NO_CONTROL*int8(ones(size(tsg.DAYD_WS)))];
  end
  sample.SSTP_QC   = [int8(sample.SSTP_QC); ...
                     NO_CONTROL*int8(ones(size(tsg.DAYD_WS)))];
  
  % INDICE is used to put back the QC once the validation procedure has
  % been applied
  % -------------------------------------------------------------------
  sample.INDICE = [sample.INDICE; [1:length(tsg.DAYD_WS)]'];
  
  % Type Used for the plots : type WS 
  % -----------------------------
  label = 'WS  ';
  m = length(tsg.DAYD_WS);
  sample.SSPS_TYPE = strvcat( sample.SSPS_TYPE, label( ones(m,1), :) );
  sample.SSTP_TYPE = strvcat( sample.SSTP_TYPE, label( ones(m,1), :) );
  
end

% Fill the structure sample with the external sample
% This measurements are of TYPE EXT
% --------------------------------------------------
if ~isempty(tsg.DAYD_EXT)

  sample.DAYD = [sample.DAYD; tsg.DAYD_EXT];
  sample.LATX = [sample.LATX; tsg.LATX_EXT];
  sample.LONX = [sample.LONX; tsg.LONX_EXT];
  
  para = { 'SSPS'; 'SSTP' };
  for i = 1 : 2    
    PARA = para{i};
    
    if ~isempty(tsg.([ PARA '_EXT']))
      sample.(PARA) = [sample.(PARA); tsg.([ PARA '_EXT']) ];
    else
      sample.(PARA) = [sample.(PARA); NaN * ones( size(tsg.DAYD_EXT)) ];
    end

    if ~isempty(tsg.([ PARA '_EXT_QC']))
      sample.([PARA '_QC']) = [int8(sample.([PARA '_QC']));...
                               tsg.([PARA '_EXT_QC'])];
    else
      sample.([PARA '_QC']) = [int8(sample.([PARA '_QC'])); ...
                               NO_CONTROL*int8(ones(size(tsg.DAYD_EXT)))];
    end

    m = length(tsg.DAYD_EXT);
    if isempty( tsg.([ PARA '_EXT_TYPE']) )
      label = 'UNKN';
      sample.([ PARA '_TYPE']) = strvcat(sample.([PARA '_TYPE']), ...
                                         label(ones(m,1),:) );
    else
      sample.([ PARA '_TYPE']) = strvcat(sample.([ PARA '_TYPE']),...
                                         tsg.SSPS_EXT_TYPE );
    end
  end

  % INDICE is used to put back the QC once the validation procedure has
  % been applied
  % -------------------------------------------------------------------
  sample.INDICE = [sample.INDICE; [1:length(tsg.DAYD_EXT)]'];

end

% Eliminate the first element if NaN
% ----------------------------------
if isnan(sample.DAYD(1))
  sample.DAYD(1)     = [];
  sample.LATX(1)     = [];
  sample.LONX(1)     = [];
  sample.SSPS(1)     = [];
  sample.SSPS_QC(1)  = [];
  sample.SSPS_TYPE(1,:)  = [];
  sample.SSTP(1)     = [];
  sample.SSTP_QC(1)  = [];
  sample.SSTP_TYPE(1,:)  = [];
  sample.INDICE(1)   = [];
end  

if ~isempty(sample.DAYD)
  
  % Sort the struct sample - increasing time.
  % -----------------------------------------  
  [sample.DAYD, iOrder] = sort(sample.DAYD);
  sample.LATX           = sample.LATX(iOrder);
  sample.LONX           = sample.LONX(iOrder);
  sample.SSPS           = sample.SSPS(iOrder);
  sample.SSPS_QC        = sample.SSPS_QC(iOrder);
  sample.SSPS_TYPE      = sample.SSPS_TYPE(iOrder,:);
  sample.SSTP           = sample.SSTP(iOrder);
  sample.SSTP_QC        = sample.SSTP_QC(iOrder);
  sample.SSTP_TYPE      = sample.SSTP_TYPE(iOrder,:);
  sample.INDICE         = sample.INDICE(iOrder);
  
  % Test if DAYD is strictly increasing
  % -----------------------------------
  increasingInd = 1:length(sample.DAYD);
  diffDay       = diff(sample.DAYD);
  ind           = find(diffDay == 0);
  if ~isempty(ind)
    increasingInd(ind) = [];
  end
  
  % put the structure sample in the tsg structure
  % ---------------------------------------------
  if ~isempty( increasingInd )
    tsg.DAYD_SPL      = sample.DAYD(increasingInd);
    tsg.LATX_SPL      = sample.LATX(increasingInd);
    tsg.LONX_SPL      = sample.LONX(increasingInd);
    tsg.INDICE_SPL    = sample.INDICE(increasingInd);

    para = { 'SSPS'; 'SSTP' };
    for i = 1 : 2
      PARA = para{i};

      tsg.([PARA '_SPL'])       = sample.(PARA)(increasingInd);
      tsg.([PARA '_SPL_QC'])    = int8(sample.([PARA '_QC'])(increasingInd));
      tsg.([PARA '_SPL_TYPE'])  = sample.([PARA '_TYPE'])(increasingInd,:);

      tsg.([PARA '_SPL_DIF'])   = NaN * ones(size(tsg.DAYD_SPL));
      tsg.([PARA '_SPL_SMOOTH'])= NaN * ones(size(tsg.DAYD_SPL));
    end
  end

end

% There are only SSTP samples. The SSJT time series should
% be compared to the SSTP samples. To simplify the soft we use a
% variable SSJT sample equals to the SSTP sample structure
% ---------------------------------------------------------------
if ~isempty( tsg.SSTP_SPL )
  tsg.SSJT_SPL         = tsg.SSTP_SPL;
  tsg.SSJT_SPL_QC      = tsg.SSTP_SPL_QC;
  tsg.SSJT_SPL_DIF     = tsg.SSTP_SPL_DIF;
  tsg.SSJT_SPL_SMOOTH  = tsg.SSTP_SPL_SMOOTH;
  tsg.SSJT_SPL_TYPE    = tsg.SSTP_SPL_TYPE;
end

% Update application data
% -----------------------
setappdata( hMainFig, 'tsg_data', tsg );
